@@ -84,7 +84,7 @@ dataUrl = "http://ilthermo.boulder.nist.gov/ILT2/ilset"
 
 def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     #JOAO
-    global prp
+    global prp, params
     #JOAO
     """ Starts a query on the Ionic Liquids Database from NIST.
 
@@ -110,10 +110,16 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     """
     if prop:
         if prop not in abr2prop.keys():
+            #JOAO
+            print("petara do baquila")
+            #JOAO
             raise propertyError(prop)
         else:
             # prp = properties[prop][0]
             prp = abr2key[prop]
+            #JOAO
+            print("prp: ",prp)
+            #JOAO
     else:
         prp = ''
     params = dict(
@@ -124,10 +130,16 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
         keyw = keywords,
         prp = prp
     )
+    #JOAO
+    print(params)
+    #JOAO
     r = requests.get(searchUrl, params=params)
     resDict = r.json()
     if len(resDict['errors']) > 0:
         e = " *** ".join(resDict['errors'])
+        #JOAO
+        print("len(resDict['errors']) > 0")
+        #JOAO
         raise queryError(e)
     return result(resDict)
 
